#!/bin/bash
# Licensed Materials - Property of IBM
# 5724-I68
#
# (C) Copyright IBM Corp. 2000, 2006
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

. ${TOP}/bin/get_params.sh

#----------------------------------------
#
# usage
#
#----------------------------------------

if [ "${_CCD_CODE}" = "" ]; then
    ${ECHO} "Usage: $0 --code=<company code> [--confirm_delete=no]"
    exit
fi


$RM $dropCtgIndexesFile

#----------------------------------------
#
# cleanup
#
#----------------------------------------

. ${DB_ROOT_DIR}/schema/util/get_cmp_id.sh --code=${_CCD_CODE} --confirm_db=no

if [ ! "${CMP_ID}" = "" ]; then
    if [ ! "${_CCD_CONFIRM_DELETE}" = "no" ]; then
        ${ECHO}
        ${ECHO} "!! company already exists."
        ${ECHO} "!! do you want to continue ? (y/n) "
        read res
        if [ ! "$res" = "y" ]; then
            ${ECHO} "!! exiting"
            exit
        fi
    fi

echo '========================================================'
echo '== Dropping indexes from catalog tables'
echo '========================================================'
dropCtgIndexesFile="tmpDropCtgIndexes.sql"

# drop catalog indexes so that updating doesn't take forever
${GREP} 'drop index' $DB_DIR/gen/idx_ctg_catalog.sql > $dropCtgIndexesFile

${CCD_SQLPLUS} ${CONNECTION} <<EOF 2>&1
set pagesize 0;
set linesize 200;
@$dropCtgIndexesFile;
commit;
EOF


${ECHO} ====================================================
${ECHO} "deleting tables for ${_CCD_CODE} (id=${CMP_ID})"
${ECHO} ====================================================

${CCD_SQLPLUS} ${CONNECTION} <<EOF
set define '&'
define CMP_ID=${CMP_ID};

drop index temp_itm_0;
create index ictg_itm_0 on tctg_itm_item (
        itm_id,
	itm_company_id
)
tablespace  INDX ;
drop index temp_icm_0;
create index temp_icm_0 on tctg_icm_item_category_map (
        icm_item_id,
        icm_company_id
)
tablespace  INDX ;
drop index temp_ita_0;
create index temp_ita_0 on tctg_ita_item_attributes (
        ita_item_id,
        ita_company_id
)
tablespace  INDX ;


DECLARE

delete_size constant number := 10000;
min_itm_id number;
max_itm_id number;
current_itm_id number;
company_id constant number := &CMP_ID;

BEGIN

select max(itm_id) into max_itm_id from tctg_itm_item where itm_company_id = company_id;
select min(itm_id) into min_itm_id from tctg_itm_item where itm_company_id = company_id;

while min_itm_id <= max_itm_id loop
delete from tctg_ita_item_attributes where ita_item_id <= min_itm_id + delete_size and ita_item_id >= min_itm_id and ita_company_id = company_id;
delete from tctg_itm_item where itm_id <= min_itm_id + delete_size and itm_id >= min_itm_id and itm_company_id = company_id;
delete from tctg_icm_item_category_map where icm_item_id <= min_itm_id + delete_size and icm_item_id >= min_itm_id and icm_company_id = company_id;
commit;
min_itm_id := min_itm_id + delete_size;
END LOOP;
END;
/

prompt ---- Deleting temporary indexes created ---;
drop index temp_itm_0;
drop index temp_icm_0;
drop index temp_ita_0;


prompt ---- now delete the other tables ---;

`cat ${DB_DIR}/gen/cleanup.sql`

EOF

echo '========================================================'
echo '== Creating indexes on catalog table'
echo '========================================================'

${CCD_SQLPLUS} ${CONNECTION} <<EOF 2>&1
set pagesize 0;
set linesize 200;
@$DB_DIR/gen/idx_ctg_catalog.sql;
commit;
EOF

${ECHO} ====================================================
${ECHO} Analyzing
${ECHO} ====================================================
cd ${TOP}/src/db/schema/util
./analyze_schema.sh --confirm_db=no

fi

