#!/bin/bash
# Licensed Materials - Property of IBM
# 5724-I68
#
# (C) Copyright IBM Corp. 2000, 2006
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

. ${TOP}/bin/get_params.sh

. ${TOP}/src/db/schema/util/set_db.sh \
    --db_user_name=${_CCD_DB_USER_NAME} \
    --db_user_pwd=${_CCD_DB_USER_PWD} \
    --db_service_name=${_CCD_DB_SERVICE_NAME}

cd $DB_DIR/util;
tempGrep="tmp_delete_old_versions.grep"
tempSed="tmp_delete_old_versions.sed"
deletefile="tmp_delete_old_versions.sql"

echo '========================================================'
echo '== Dropping indexes from catalog tables'
echo '========================================================'
dropCtgIndexesFile="tmpDropCtgIndexes.sql"

# drop catalog indexes so that updating doesn't take forever
${GREP} 'drop index' $DB_DIR/gen/idx_ctg_catalog.sql > $dropCtgIndexesFile

${CCD_SQLPLUS} ${CONNECTION} <<EOF 2>&1
set pagesize 0;
set linesize 200;
@$dropCtgIndexesFile;
commit;
EOF

$RM $dropCtgIndexesFile


${ECHO} ====================================================
${ECHO} 'generating sql for deleting old versions'
${ECHO} ====================================================

${GREP} '^  *.*_next_version_id' $DB_DIR/gen/ddl_ctg_catalog.sql > $tempGrep

${SED} 's/^  *\(...\)_.*/delete from \1 where \1_next_version_id != 999999999;/g' $tempGrep > $tempSed
${SED} 's/^  *\(...\)_.*/update \1 set \1_version_id = 0;/g' $tempGrep >> $tempSed

# remove ita, itm and icm because if they are huge the delete might run out of rollback segment
${GREP} -v -e 'ita' -e 'itm' -e 'icm' -e 'unique' $tempSed > $deletefile

${ECHO} ====================================================
${ECHO} 'running the generated sql for deleting old versions'
${ECHO} ====================================================

echo 'CONNECTION: ' $CONNECTION

${CCD_SQLPLUS} ${CONNECTION} <<EOF 2>&1
set pagesize 0;
set linesize 200;
set timing on;
set define '&';

set heading off;
drop index temp_itm_0;
create index temp_itm_0 on tctg_itm_item (
        itm_id,
        itm_next_version_id
)
tablespace  INDX ;

analyze index temp_itm_0 estimate statistics;

drop index temp_icm_0;
create index temp_icm_0 on tctg_icm_item_category_map (
        icm_item_id,
        icm_next_version_id
)
tablespace  INDX ;

analyze index temp_icm_0 estimate statistics;

drop index temp_ita_0;
create index temp_ita_0 on tctg_ita_item_attributes (
        ita_item_id,
        ita_next_version_id
)
tablespace  INDX ;

analyze index temp_ita_0 estimate statistics;

prompt ---- Running a stored procedure to delete old versions from ITA,ITM, and ICM tables ----;

DECLARE

delete_size constant number := 10000;
min_itm_id number;
max_itm_id number;
current_itm_id number;

BEGIN

select max(itm_id) into max_itm_id from tctg_itm_item ;
select min(itm_id) into min_itm_id from tctg_itm_item ;

while min_itm_id <= max_itm_id loop
delete from tctg_ita_item_attributes where ita_item_id <= min_itm_id + delete_size and ita_item_id >= min_itm_id and ita_next_version_id != 999999999;
update tctg_ita_item_attributes set ita_version_id = 0 where ita_item_id <= min_itm_id + delete_size and ita_item_id >= min_itm_id;
commit;
delete from tctg_itm_item where itm_id <= min_itm_id + delete_size and itm_id >= min_itm_id and itm_next_version_id != 999999999;
update tctg_itm_item set itm_version_id = 0 where itm_id <= min_itm_id + delete_size and itm_id >= min_itm_id;
commit;
delete from tctg_icm_item_category_map where icm_item_id <= min_itm_id + delete_size and icm_item_id >= min_itm_id and icm_next_version_id != 999999999;
update tctg_icm_item_category_map set icm_version_id = 0 where icm_item_id <= min_itm_id + delete_size and icm_item_id >= min_itm_id;
commit;
min_itm_id := min_itm_id + delete_size;
END LOOP;
END;
/
prompt ---- Deleting temporary indexes crated ---;

drop index temp_itm_0;
drop index temp_icm_0;
drop index temp_ita_0;

prompt ---- Deleting versions information from VER table ---;

delete from ver where ver_type not in ('FIRST_VERSION','Dummy System Entry');
commit;

select '---- Deleting old version from other tables ---' from dual;

@$deletefile;
commit;

EOF

${RM} $tempGrep
${RM} $tempSed
${RM} $deletefile

echo '========================================================'
echo '== Creating indexes on catalog table'
echo '========================================================'

${CCD_SQLPLUS} ${CONNECTION} <<EOF 2>&1
set pagesize 0;
set linesize 200;
@$DB_DIR/gen/idx_ctg_catalog.sql;
commit;
EOF

${ECHO} ====================================================
${ECHO} Analyzing
${ECHO} ====================================================
cd ${TOP}/src/db/schema/util
./analyze_schema.sh --confirm_db=no

